@@ -9,7 +9,7 @@ def create_executor(robot_name, category):
     config_db = db.config.find_one()
 
     packages = config_db["packages"]
-    package = filter(lambda x: x["category"] == category, packages)[0]
+    package = list(filter(lambda x: x["category"] == category, packages)[0])
 
     module = importlib.import_module(package["name"] + ".executor")
     class_ = getattr(module, package["class"])
